# Contributing to PlasmaPy

[code of conduct]: https://docs.plasmapy.org/en/stable/CODE_OF_CONDUCT.html
[contributor guide]: https://docs.plasmapy.org/en/latest/contributing/index.html

Thank you for your interest in contributing to PlasmaPy — we really
appreciate it!

For more information on how to contribute, please check out our
[contributor guide] and our [code of conduct].
